==> google-cloud-sdk-433.0.1-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/policy_intelligence/troubleshoot_policy/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command group for Policy Intelligence Troubleshoot Policy."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@base.Hidden
class TroubleshootAlpha(base.Group):
  """Troubleshoot IAM policies."""

  detailed_help = {
      'DESCRIPTION': """\
          Troubleshoot IAM policies.

          More information can be found here:
          https://cloud.google.com/iam/docs/troubleshooting-access
      """
  }


@base.ReleaseTracks(base.ReleaseTrack.BETA)
@base.Hidden
class TroubleshootBeta(base.Group):
  """Troubleshoot IAM policies."""

  detailed_help = {
      'DESCRIPTION': """\
          Troubleshoot IAM policies.

          More information can be found here:
          https://cloud.google.com/iam/docs/troubleshooting-access
      """
  }

==> google-cloud-sdk-559.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/policy_intelligence/troubleshoot_policy/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command group for Policy Intelligence Troubleshoot Policy."""


from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@base.Hidden
class TroubleshootAlpha(base.Group):
  """Troubleshoot IAM policies."""

  detailed_help = {'DESCRIPTION': """\
          Troubleshoot IAM policies.

          More information can be found here:
          https://cloud.google.com/iam/docs/troubleshooting-access
      """}


@base.ReleaseTracks(base.ReleaseTrack.BETA)
@base.Hidden
class TroubleshootBeta(base.Group):
  """Troubleshoot IAM policies."""

  detailed_help = {'DESCRIPTION': """\
          Troubleshoot IAM policies.

          More information can be found here:
          https://cloud.google.com/iam/docs/troubleshooting-access
      """}


@base.ReleaseTracks(base.ReleaseTrack.GA)
class Troubleshoot(base.Group):
  """Troubleshoot IAM policies."""

  detailed_help = {'DESCRIPTION': """\
          Troubleshoot IAM policies.

          More information can be found here:
          https://cloud.google.com/iam/docs/troubleshooting-access
      """}
